package com.ruoyi.inspection.service;

import java.util.List;
import com.ruoyi.inspection.domain.InspectionManageTable;
import com.ruoyi.inspection.domain.InspectionRecordTable;
import com.ruoyi.inspection.domain.VoViewInspectionRecordTable;

/**
 * 巡检点管理Service接口
 * 
 * @author ruoyi
 * @date 2024-08-29
 */
public interface IInspectionManageTableService 
{
    /**
     * 查询巡检点管理
     * 
     * @param id 巡检点管理主键
     * @return 巡检点管理
     */
    public InspectionManageTable selectInspectionManageTableById(Long id);

    /**
     * 查询巡检点管理列表
     * 
     * @param inspectionManageTable 巡检点管理
     * @return 巡检点管理集合
     */
    public List<InspectionManageTable> selectInspectionManageTableList(InspectionManageTable inspectionManageTable);

    /**
     * 新增巡检点管理
     * 
     * @param inspectionManageTable 巡检点管理
     * @return 结果
     */
    public int insertInspectionManageTable(InspectionManageTable inspectionManageTable);

    /**
     * 修改巡检点管理
     * 
     * @param inspectionManageTable 巡检点管理
     * @return 结果
     */
    public int updateInspectionManageTable(InspectionManageTable inspectionManageTable);

    /**
     * 批量删除巡检点管理
     * 
     * @param ids 需要删除的巡检点管理主键集合
     * @return 结果
     */
    public int deleteInspectionManageTableByIds(Long[] ids);

    /**
     * 删除巡检点管理信息
     * 
     * @param id 巡检点管理主键
     * @return 结果
     */
    public int deleteInspectionManageTableById(Long id);



}
